@@ -1,4 +1,4 @@
-__version__ = '0.0.17'
+__version__ = '0.0.20'
 
 import evaics.sdk as sdk
 from types import SimpleNamespace
@@ -107,7 +107,8 @@ def finish_api_request(request_id):
 
 class LegacyNode:
 
-    def __init__(self, id, key, key_ln, reload_interval, timeout, controllers):
+    def __init__(self, id, key_id, key_lid, reload_interval, timeout,
+                 controllers):
         self.id = id
         for c in controllers:
             if c not in ['uc', 'lm']:
@@ -116,15 +117,15 @@ class LegacyNode:
         self.online = False
         self.reload_interval = reload_interval
         self._last_reload = 0
-        self.key = key
-        self.key_ln = key_ln
+        self.key_id = key_id
+        self.key_lid = key_lid
         self.timeout = timeout
         self.need_reload = threading.Event()
         self.build = None
         self.version = None
 
     def call(self, ctype, method, params=None):
-        key_val = get_key_val(self.key)
+        key_val = get_key_val(self.key_id)
         if params is None:
             params = {'k': key_val}
         else:
@@ -140,7 +141,7 @@ class LegacyNode:
         data = rid + zlib.compress(pack(payload))
         cb = Callback()
         send_api_request(
-            request_id, controller_id, header + self.key_ln.encode() + b'\x00' +
+            request_id, controller_id, header + self.key_lid.encode() + b'\x00' +
             encrypt(data, private_key, key_is_hash=True), cb.data_handler)
         if not cb.completed.wait(self.timeout):
             finish_api_request(request_id)
@@ -169,8 +170,8 @@ class LegacyNode:
         d['id'] = self.id
         d['controllers'] = self.controllers
         d['online'] = self.online
-        d['key'] = self.key
-        d['key_legacy'] = self.key_ln
+        d['key_id'] = self.key_id
+        d['key_legacy_id'] = self.key_lid
         d['reload_interval'] = self.reload_interval
         d['timeout'] = self.timeout
         d['build'] = self.build
@@ -533,12 +534,12 @@ def run():
     if 'password' in pubsub_cfg and pubsub_cfg['password'] is None:
         del pubsub_cfg['password']
     for id, c in config.get('nodes', {}).items():
-        key = c['key']
-        key_ln = c['key_legacy_name']
+        key_id = c['key_id']
+        key_lid = c['key_legacy_id']
         reload_interval = c['reload_interval']
         timeout = c.get('timeout', service.timeout['default'])
         controllers = c.get('controllers', [])
-        c = LegacyNode(id, key, key_ln, reload_interval, timeout, controllers)
+        c = LegacyNode(id, key_id, key_lid, reload_interval, timeout, controllers)
         _d.lc[id] = c
         mark_node(c.id, 'offline')
     pubsub = psrt.Client(**pubsub_cfg)
